@@ -41,13 +41,13 @@ agora_local_audio_track_enable_ear_monitor = agora_lib.agora_local_audio_track_e
 agora_local_audio_track_enable_ear_monitor.restype = ctypes.c_int
 agora_local_audio_track_enable_ear_monitor.argtypes = [AGORA_HANDLE, ctypes.c_int, ctypes.c_int]
 
-# agora_local_audio_track_set_max_buffer_audio_frame_number = agora_lib.agora_local_audio_track_set_max_bufferd_frame_number
-# agora_local_audio_track_set_max_buffer_audio_frame_number.restype = None
-# agora_local_audio_track_set_max_buffer_audio_frame_number.argtypes = [AGORA_HANDLE, ctypes.c_int]
+agora_local_audio_track_set_max_buffer_audio_frame_number = agora_lib.agora_local_audio_track_set_max_bufferd_frame_number
+agora_local_audio_track_set_max_buffer_audio_frame_number.restype = None
+agora_local_audio_track_set_max_buffer_audio_frame_number.argtypes = [AGORA_HANDLE, ctypes.c_int]
 
-# agora_local_audio_track_clear_buffer = agora_lib.agora_local_audio_track_clear_sender_buffer
-# agora_local_audio_track_clear_buffer.restype = ctypes.c_int
-# agora_local_audio_track_clear_buffer.argtypes = [AGORA_HANDLE]
+agora_local_audio_track_clear_buffer = agora_lib.agora_local_audio_track_clear_sender_buffer
+agora_local_audio_track_clear_buffer.restype = ctypes.c_int
+agora_local_audio_track_clear_buffer.argtypes = [AGORA_HANDLE]
 
 
 class LocalAudioTrack:
@@ -60,8 +60,6 @@ class LocalAudioTrack:
     def is_enabled(self):
         enabled = ctypes.c_int()
         ret = agora_local_audio_track_is_enabled(self.track_handle, ctypes.byref(enabled))
-        if ret != 0:
-            logger.error(f"Failed to get local audio track enabled state, error code: {ret}")
         return ret, enabled.value
 
     def get_state(self):
@@ -81,37 +79,27 @@ class LocalAudioTrack:
 
     def adjust_publish_volume(self, volume):
         ret = agora_local_audio_track_adjust_publish_volume(self.track_handle, volume)
-        if ret != 0:
-            logger.error(f"Failed to adjust publish volume, error code: {ret}")
         return ret
 
     def get_publish_volume(self):
         volume = ctypes.c_int()
         ret = agora_local_audio_track_get_publish_volume(self.track_handle, ctypes.byref(volume))
-        if ret != 0:
-            logger.error(f"Failed to get publish volume, error code: {ret}")
         return ret, volume.value
 
     def enable_local_playback(self, enable):
         ret = agora_local_audio_track_enable_local_playback(self.track_handle, enable)
-        if ret != 0:
-            logger.error(f"Failed to enable local playback, error code: {ret}")
         return ret
 
     def enable_ear_monitor(self, enable, include_audio_filter):
         ret = agora_local_audio_track_enable_ear_monitor(self.track_handle, enable, include_audio_filter)
-        if ret != 0:
-            logger.error(f"Failed to enable ear monitor, error code: {ret}")
         return ret
 
-    # def set_max_buffer_audio_frame_number(self, num):
-    #     agora_local_audio_track_set_max_buffer_audio_frame_number(self.track_handle, num)
+    def set_max_buffer_audio_frame_number(self, num):
+        agora_local_audio_track_set_max_buffer_audio_frame_number(self.track_handle, num)
 
-    # def clear_buffer(self):
-    #     ret = agora_local_audio_track_clear_buffer(self.track_handle)
-    #     if ret != 0:
-    #         logger.error(f"Failed to clear buffer, error code: {ret}")
-    #     return ret
+    def clear_sender_buffer(self):
+        ret = agora_local_audio_track_clear_buffer(self.track_handle)
+        return ret
 
     def release(self):
         pass
